#' Working with netCDF for Essential Biodiversity Variables
#'
#'
#' This package can be used to easily access the data of the EBV netCDFs which
#' can be downloaded from the \href{https://portal.geobon.org/home}{Geobon Portal}. It also
#' provides some basic visualization of the data.  Advanced users can build
#' their own netCDFs with the EBV standard using this package.
#'
#' This package contains three main usecases: accessing the data, visualising
#' it and creating your own data in the EBV netCDF
#' standard.
#'
#'
#' @name ebvcube
"_PACKAGE"
